==> google-sheets-telegram-utils-0.0.4.tar.gz: google-sheets-telegram-utils-0.0.4/google_sheets_telegram_utils/utils/google_sheet_utils.py <==
import gspread
from oauth2client.service_account import ServiceAccountCredentials

from google_sheets_telegram_utils.exceptions import RowDoesNotExistException


class GoogleSheetConfig:
    def __init__(self, credentials_path, scope, file, sheet_name):
        self.credentials_path = credentials_path
        self.scope = scope
        self.file = file
        self.sheet_name = sheet_name


class GoogleSheetConnector:
    def __init__(self, config: GoogleSheetConfig):
        self.config = config

    def get_data_from_sheet(self) -> dict:
        workbook = self.get_workbook()
        sheet = workbook.worksheet(self.config.sheet_name)
        data = sheet.get_all_records()
        return data

    def get_workbook(self) -> gspread.models.Spreadsheet:
        credentials = ServiceAccountCredentials.from_json_keyfile_name(
            self.config.credentials_path,
            self.config.scope,
        )
        client = gspread.authorize(credentials)
        sheet = client.open(self.config.file)
        return sheet

    def add_rows(self, rows: list) -> None:
        workbook = self.get_workbook()
        worksheet = workbook.worksheet(self.config.sheet_name)
        records = worksheet.get_all_records()
        insert_position = len(records) + 2
        worksheet.insert_rows(rows, insert_position)

    def add_row(self, row):
        return self.add_rows([row])

    def get_row_by_id(self, pk) -> dict:
        rows = self.get_data_from_sheet()
        filtered_rows = list(filter(lambda row: row['id'] == pk, rows))
        if filtered_rows:
            data = filtered_rows[0]
            return data
        raise RowDoesNotExistException

==> google-sheets-telegram-utils-0.0.5.tar.gz: google-sheets-telegram-utils-0.0.5/google_sheets_telegram_utils/utils/google_sheet_utils.py <==
import gspread
from oauth2client.service_account import ServiceAccountCredentials

from google_sheets_telegram_utils.exceptions import RowDoesNotExistException


class GoogleSheetConfig:
    def __init__(self, credentials_path, scope, file, sheet_name):
        self.credentials_path = credentials_path
        self.scope = scope
        self.file = file
        self.sheet_name = sheet_name


class GoogleSheetConnector:
    def __init__(self, config: GoogleSheetConfig):
        self.config = config

    def get_data_from_sheet(self) -> dict:
        workbook = self.get_workbook()
        sheet = workbook.worksheet(self.config.sheet_name)
        data = sheet.get_all_records()
        return data

    def get_workbook(self) -> gspread.models.Spreadsheet:
        credentials = ServiceAccountCredentials.from_json_keyfile_name(
            self.config.credentials_path,
            self.config.scope,
        )
        client = gspread.authorize(credentials)
        sheet = client.open(self.config.file)
        return sheet

    def add_rows(self, rows: list) -> None:
        workbook = self.get_workbook()
        worksheet = workbook.worksheet(self.config.sheet_name)
        records = worksheet.get_all_records()
        insert_position = len(records) + 2
        worksheet.insert_rows(rows, insert_position, value_input_option='USER_ENTERED')

    def add_row(self, row):
        return self.add_rows([row])

    def get_row_by_id(self, pk) -> dict:
        rows = self.get_data_from_sheet()
        filtered_rows = list(filter(lambda row: row['id'] == pk, rows))
        if filtered_rows:
            data = filtered_rows[0]
            return data
        raise RowDoesNotExistException
